

set -ex



test -L $PREFIX/lib/libcusolver.so.11
test -L $PREFIX/lib/libcusolver.so.11.6.4.69
test -L $PREFIX/targets/sbsa-linux/lib/libcusolver.so.11
test -f $PREFIX/targets/sbsa-linux/lib/libcusolver.so.11.6.4.69
test -L $PREFIX/lib/libcusolverMg.so.11
test -L $PREFIX/lib/libcusolverMg.so.11.6.4.69
test -L $PREFIX/targets/sbsa-linux/lib/libcusolverMg.so.11
test -f $PREFIX/targets/sbsa-linux/lib/libcusolverMg.so.11.6.4.69
exit 0
